==> fantacalciobazar_0.4.tar.gz: fantacalciobazar/giornata.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_admin_errata == "NO") {



$num_giornata = substr($giornata,8);

if ($copia_file_voti and $posizione_file) {
if (@is_file("$percorso_cartella_voti/voti$num_giornata.txt")) {
echo "file gi esistente, non copiato.";
$copiare = "NO";
} # fine if (@is_file("$percorso_cartella_dati/voti$num_giornata.txt"))
$lock = fopen("$percorso_cartella_dati/admin.lock","w+");
flock($lock,2);
$voti = @file($posizione_file);
if (!$voti) {
echo "<b>file non trovato.</b>";
$copiare = "NO";
} # fine if (!$voti)
if ($copiare != "NO") {
$num_voti = count($voti);
$filevoti = fopen("$percorso_cartella_voti/voti$num_giornata.txt","w+");
flock($filevoti,2);
rewind($filevoti);
for ($num1 = 0 ; $num1 < $num_voti ; $num1++) {
fwrite($filevoti,$voti[$num1]);
} # fine for $num1
flock($filevoti,3);
fclose($filevoti);
} # fine if ($copiare != "NO")
flock($lock,3);
fclose($lock);
} # fine if ($copia_file_voti and $posizione_file)


echo "<center><b>$giornata</b></center>";
$tab_formazioni = "<tr>";
$num_colonne = 0;
$punti = "";
$num2 = 0;
$leggendo_formazioni = "SI";
$leggendo_punteggi = "NO";
$punteggi_esistenti = "NO";

$file_giornata = file("$percorso_cartella_dati/$giornata");
$num_linee_file_giornata = count($file_giornata);
for($num1 = 0 ; $num1 < $num_linee_file_giornata; $num1++) {
$linea = substr($file_giornata[$num1],0,-1);
if ($linea == "#@& fine formazioni #@&") $leggendo_formazioni = "NO";
if ($leggendo_formazioni == "SI") {
if ($linea == "#@& formazione #@&") $giocatore = "";
if ($giocatore) {
${$formazione}[$num2] = $file_giornata[$num1];
$num2++;
} # fine if ($giocatore)
if ($aggiorna_giocatore) {
$giocatore = $linea;
$formazione = "formazione_$giocatore";
$num2 = 0;
$aggiorna_giocatore = "";
} # fine if ($aggiorna_giocatore)
if ($linea == "#@& formazione #@&") $aggiorna_giocatore = "SI";
} # fine if ($leggendo_formazioni == "SI")

if ($linea == "#@& fine voti #@&") $leggendo_voti = "NO";
if ($leggendo_voti == "SI") {
$voti[$num2] = $linea;
$num2++;
} # fine if ($leggendo_voti == "SI")
if ($linea == "#@& voti #@&") {
$leggendo_voti = "SI";
$voti_esistenti = "SI";
$num2 = 0;
} # fine if ($linea == "#@& voti #@&")

if ($linea == "#@& fine punteggi #@&") $leggendo_punteggi = "NO";
if ($leggendo_punteggi == "SI") {
$punteggi[$num2] = $linea;
$num2++;
} # fine if ($leggendo_punteggi == "SI")
if ($linea == "#@& punteggi #@&") {
$leggendo_punteggi = "SI";
$punteggi_esistenti = "SI";
$num2 = 0;
} # fine if ($linea == "#@& punteggi #@&")
} # fine for $num1


$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);

if ($num_colonne >= 3) {
$tab_formazioni .= "</tr><tr>";
$num_colonne = 0;
} # fine if ($num_colonne >= 3)
$num_colonne++;
$tab_formazioni .= "<td>Squadra di $giocatore<br><br>";
$formazione = "formazione_$giocatore";
$formazione = $$formazione;
$num_linee_formazione = count($formazione);
for ($num2 = 0 ; $num2 < $num_linee_formazione; $num2++) {
$formazione[$num2] = ereg_replace(" ","_",$formazione[$num2]);
$tab_formazioni .= $formazione[$num2]."<br>";
} # fine for $num2
$tab_formazioni .= "</td>
";

next($pass);
} # fine for $num1
for ($num1 = $num_colonne ; $num1 < 3; $num1++) $tab_formazioni .= "<td>&nbsp;</td>";
$tab_formazioni .= "</tr>";

echo "<table align=\"center\" border=\"1\">$tab_formazioni</table>";

if ($voti_esistenti == "SI") {
echo "<table><tr><td>Voti_della_$giornata<br>";
$num_voti = count($voti);
for ($num1 = 0 ; $num1 < $num_voti ; $num1++) {
$dati_voti = explode("##@@&&", $voti[$num1]);
settype($dati_voti[1],"double");
echo $dati_voti[0].": ".$dati_voti[1]."<br>";
$voto[$dati_voti[0]] = $dati_voti[1];
} # fine for $num1
echo "</td>";

$tipo_campionato = "";
$num_giornata = str_replace("giornata","",$giornata);
if (substr($num_giornata,0,1) == 0) $num_giornata = substr($num_giornata,1);
$num_campionati = count($campionato);
reset($campionato);
for($num1 = 0 ; $num1 < $num_campionati; $num1++) {
$key_campionato = key($campionato);
$giornate_campionato = explode("-",$key_campionato);
if ($num_giornata <= $giornate_campionato[1] and $num_giornata >= $giornate_campionato[0]) {
$num_giornata_campionato = $num_giornata - $giornate_campionato[0] + 1;
$tipo_campionato = $campionato[$key_campionato];
$g_inizio_campionato = $giornate_campionato[0];
break;
} # fine if ($num_giornata <= $giornate_campionato[1] and...
next($campionato);
} # fine for $num1
if (!$tipo_campionato) $tipo_campionato = "N";

if ($tipo_campionato != "N") {

echo "<td>Punteggi_della_$giornata<br>";
$num_punteggi = count($punteggi);
for ($num1 = 0 ; $num1 < $num_punteggi ; $num1++) {
$dati_punteggio = explode("##@@&&", $punteggi[$num1]);
settype($dati_punteggio[1],"double");
echo $dati_punteggio[0].": ".$dati_punteggio[1]."<br>";
$punti[$dati_punteggio[0]] = $dati_punteggio[1];
} # fine for $num1

# calcolo la classifica fino a questa giornata
$num_giornata = ereg_replace("giornata","",$giornata);
for ($num1 = $g_inizio_campionato ; $num1 < $num_giornata ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata_punti = "giornata$num1";
if (@is_file("$percorso_cartella_dati/$giornata_punti")) {
$file_giornata_p = @file("$percorso_cartella_dati/$giornata_punti");
$num_linee_file_giornata_p = count($file_giornata_p);
$leggendo_punteggi = "NO";
$punteggi_esistenti_p = "NO";
for($num2 = 0 ; $num2 < $num_linee_file_giornata_p; $num2++) {
$linea = substr($file_giornata_p[$num2],0,-1);
if ($linea == "#@& fine punteggi #@&") $leggendo_punteggi = "NO";
if ($leggendo_punteggi == "SI") {
$punteggi_p[$num3] = $file_giornata_p[$num2];
$num3++;
} # fine if ($leggendo_punteggi == "SI")
if ($linea == "#@& punteggi #@&") {
$leggendo_punteggi = "SI";
$punteggi_esistenti_p = "SI";
$num3 = 0;
} # fine if ($leggendo_punteggi == "SI")
} # fine for $num1
if ($punteggi_esistenti_p == "SI") {
$num_punteggi_p = count($punteggi_p);
for ($num2 = 0 ; $num2 < $num_punteggi_p ; $num2++) {
$dati_punteggio = explode("##@@&&", $punteggi_p[$num2]);
settype($dati_punteggio[1],"double");
$punti[$dati_punteggio[0]] = ($punti[$dati_punteggio[0]] + $dati_punteggio[1]);
} # fine for $num2
} # fine if ($punteggi_esistenti_p == "SI")
} # fine if (@is_file("$percorso_cartella_dati/$giornata_punti"))
} # fine for $num1

echo "</td><td>Classifica_alla_giornata_$num_giornata_campionato<br>";
$num_giocatori=count($pass);
reset($pass);
for ($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
echo $giocatore.": ".$punti[$giocatore]."<br>";
next($pass);
} # fine for $num1
echo "</td></tr></table>";
echo "<center>Giornata chiusa.</center><br>";

} # fine if ($tipo_campionato != "N")

} # fine if ($voti_esistenti == "SI")

else {
if (@is_file("$percorso_cartella_voti/voti$num_giornata.txt")) {
echo "<center><form method=\"post\" action=\"calcola_punti_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"calcola\" value=\"Calcola i punteggi\">
</form></center>";
} # fine if (@is_file("$percorso_cartella_dati/voti$num_giornata.txt"))

else {
if ($prima_parte_pos_file_voti or $num_giornata_file_voti == "SI") {
$posizione_file = $prima_parte_pos_file_voti;
if ($num_giornata_file_voti == "SI") {
#$num_giornata = ereg_replace("giornata","",$giornata);
$num_giornata = $num_giornata + $diff_num_giornata_file;
if ($num_giornata_file_voti_doppio == "SI") {
if (strlen($num_giornata) == 1) $num_giornata = "0".$num_giornata;
} # fine if ($num_giornata_file_voti_doppio == "SI")
$posizione_file .= "$num_giornata".$seconda_parte_pos_file_voti;
} # fine if ($num_giornata_file_voti == "SI")
echo "<form method=\"post\" action=\"giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"copia_file_voti\" value=\"Copia i voti\">
 dal file <input type=\"text\" name=\"posizione_file\" value=\"$posizione_file\" size=\"65\">
</form>";
} # fine if ($prima_parte_pos_file_voti or...
else echo "<center>Copia il file voti$num_giornata.txt nella cartella dati.</center><br>";
} # fine else if (@is_file("$percorso_cartella_dati/voti$num_giornata.txt"))
} # fine else if ($voti_esistenti == "SI"))

echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";

} # fine if ($pass_admin_errata == "NO")

include("$percorso_cartella_dati/foot.php");
?>

==> fantacalciobazar_0.5.tar.gz: fantacalciobazar/giornata.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_admin_errata == "NO") {



$num_giornata = substr($giornata,8);

if ($copia_file_voti and $posizione_file) {
if (@is_file("$percorso_cartella_voti/voti$num_giornata.txt")) {
echo "file gi esistente, non copiato.";
$copiare = "NO";
} # fine if (@is_file("$percorso_cartella_dati/voti$num_giornata.txt"))
$lock = fopen("$percorso_cartella_dati/admin.lock","w+");
flock($lock,2);
$voti = @file($posizione_file);
if (!$voti) {
echo "<b>file non trovato.</b>";
$copiare = "NO";
} # fine if (!$voti)
if ($copiare != "NO") {
$num_voti = count($voti);
$filevoti = fopen("$percorso_cartella_voti/voti$num_giornata.txt","w+");
flock($filevoti,2);
rewind($filevoti);
for ($num1 = 0 ; $num1 < $num_voti ; $num1++) {
fwrite($filevoti,$voti[$num1]);
} # fine for $num1
flock($filevoti,3);
fclose($filevoti);
} # fine if ($copiare != "NO")
flock($lock,3);
fclose($lock);
} # fine if ($copia_file_voti and $posizione_file)


echo "<center><b>$giornata</b></center>";
$tab_formazioni = "<tr>";
$num_colonne = 0;
$punti = "";
$num2 = 0;
$leggendo_formazioni = "SI";
$leggendo_punteggi = "NO";
$punteggi_esistenti = "NO";

$file_giornata = file("$percorso_cartella_dati/$giornata");
$num_linee_file_giornata = count($file_giornata);
for($num1 = 0 ; $num1 < $num_linee_file_giornata; $num1++) {
$linea = togli_acapo($file_giornata[$num1]);
if ($linea == "#@& fine formazioni #@&") $leggendo_formazioni = "NO";
if ($leggendo_formazioni == "SI") {
if ($linea == "#@& formazione #@&") $giocatore = "";
if ($giocatore) {
${$formazione}[$num2] = $file_giornata[$num1];
$num2++;
} # fine if ($giocatore)
if ($aggiorna_giocatore) {
$giocatore = $linea;
$formazione = "formazione_$giocatore";
$num2 = 0;
$aggiorna_giocatore = "";
} # fine if ($aggiorna_giocatore)
if ($linea == "#@& formazione #@&") $aggiorna_giocatore = "SI";
} # fine if ($leggendo_formazioni == "SI")

if ($linea == "#@& fine voti #@&") $leggendo_voti = "NO";
if ($leggendo_voti == "SI") {
$voti[$num2] = $linea;
$num2++;
} # fine if ($leggendo_voti == "SI")
if ($linea == "#@& voti #@&") {
$leggendo_voti = "SI";
$voti_esistenti = "SI";
$num2 = 0;
} # fine if ($linea == "#@& voti #@&")

if ($linea == "#@& fine punteggi #@&") $leggendo_punteggi = "NO";
if ($leggendo_punteggi == "SI") {
$punteggi[$num2] = $linea;
$num2++;
} # fine if ($leggendo_punteggi == "SI")
if ($linea == "#@& punteggi #@&") {
$leggendo_punteggi = "SI";
$punteggi_esistenti = "SI";
$num2 = 0;
} # fine if ($linea == "#@& punteggi #@&")
} # fine for $num1


$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);

if ($num_colonne >= 3) {
$tab_formazioni .= "</tr><tr>";
$num_colonne = 0;
} # fine if ($num_colonne >= 3)
$num_colonne++;
$tab_formazioni .= "<td>Squadra di $giocatore<br><br>";
$formazione = "formazione_$giocatore";
$formazione = $$formazione;
$num_linee_formazione = count($formazione);
for ($num2 = 0 ; $num2 < $num_linee_formazione; $num2++) {
$formazione[$num2] = ereg_replace(" ","_",$formazione[$num2]);
$tab_formazioni .= $formazione[$num2]."<br>";
} # fine for $num2
$tab_formazioni .= "</td>
";

next($pass);
} # fine for $num1
for ($num1 = $num_colonne ; $num1 < 3; $num1++) $tab_formazioni .= "<td>&nbsp;</td>";
$tab_formazioni .= "</tr>";

echo "<table align=\"center\" border=\"1\">$tab_formazioni</table>";

if ($voti_esistenti == "SI") {
echo "<table><tr><td>Voti_della_$giornata<br>";
$num_voti = count($voti);
for ($num1 = 0 ; $num1 < $num_voti ; $num1++) {
$dati_voti = explode("##@@&&", $voti[$num1]);
settype($dati_voti[1],"double");
echo $dati_voti[0].": ".$dati_voti[1]."<br>";
$voto[$dati_voti[0]] = $dati_voti[1];
} # fine for $num1
echo "</td>";

$tipo_campionato = "";
$num_giornata = str_replace("giornata","",$giornata);
if (substr($num_giornata,0,1) == 0) $num_giornata = substr($num_giornata,1);
$num_campionati = count($campionato);
reset($campionato);
for($num1 = 0 ; $num1 < $num_campionati; $num1++) {
$key_campionato = key($campionato);
$giornate_campionato = explode("-",$key_campionato);
if ($num_giornata <= $giornate_campionato[1] and $num_giornata >= $giornate_campionato[0]) {
$num_giornata_campionato = $num_giornata - $giornate_campionato[0] + 1;
$tipo_campionato = $campionato[$key_campionato];
$g_inizio_campionato = $giornate_campionato[0];
break;
} # fine if ($num_giornata <= $giornate_campionato[1] and...
next($campionato);
} # fine for $num1
if (!$tipo_campionato) $tipo_campionato = "N";

if ($tipo_campionato != "N") {

echo "<td>Punteggi_della_$giornata<br>";
$num_punteggi = count($punteggi);
for ($num1 = 0 ; $num1 < $num_punteggi ; $num1++) {
$dati_punteggio = explode("##@@&&", $punteggi[$num1]);
settype($dati_punteggio[1],"double");
echo $dati_punteggio[0].": ".$dati_punteggio[1]."<br>";
$punti[$dati_punteggio[0]] = $dati_punteggio[1];
} # fine for $num1

# calcolo la classifica fino a questa giornata
$num_giornata = ereg_replace("giornata","",$giornata);
for ($num1 = $g_inizio_campionato ; $num1 < $num_giornata ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata_punti = "giornata$num1";
if (@is_file("$percorso_cartella_dati/$giornata_punti")) {
$file_giornata_p = @file("$percorso_cartella_dati/$giornata_punti");
$num_linee_file_giornata_p = count($file_giornata_p);
$leggendo_punteggi = "NO";
$punteggi_esistenti_p = "NO";
for($num2 = 0 ; $num2 < $num_linee_file_giornata_p; $num2++) {
$linea = togli_acapo($file_giornata_p[$num2]);
if ($linea == "#@& fine punteggi #@&") $leggendo_punteggi = "NO";
if ($leggendo_punteggi == "SI") {
$punteggi_p[$num3] = $file_giornata_p[$num2];
$num3++;
} # fine if ($leggendo_punteggi == "SI")
if ($linea == "#@& punteggi #@&") {
$leggendo_punteggi = "SI";
$punteggi_esistenti_p = "SI";
$num3 = 0;
} # fine if ($leggendo_punteggi == "SI")
} # fine for $num1
if ($punteggi_esistenti_p == "SI") {
$num_punteggi_p = count($punteggi_p);
for ($num2 = 0 ; $num2 < $num_punteggi_p ; $num2++) {
$dati_punteggio = explode("##@@&&", $punteggi_p[$num2]);
settype($dati_punteggio[1],"double");
$punti[$dati_punteggio[0]] = ($punti[$dati_punteggio[0]] + $dati_punteggio[1]);
} # fine for $num2
} # fine if ($punteggi_esistenti_p == "SI")
} # fine if (@is_file("$percorso_cartella_dati/$giornata_punti"))
} # fine for $num1

echo "</td><td>Classifica_alla_giornata_$num_giornata_campionato<br>";
$num_giocatori=count($pass);
reset($pass);
for ($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
echo $giocatore.": ".$punti[$giocatore]."<br>";
next($pass);
} # fine for $num1
echo "</td></tr></table>";
echo "<center>Giornata chiusa.</center><br>";

} # fine if ($tipo_campionato != "N")

} # fine if ($voti_esistenti == "SI")

else {
if (@is_file("$percorso_cartella_voti/voti$num_giornata.txt")) {
echo "<center><form method=\"post\" action=\"calcola_punti_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"calcola\" value=\"Calcola i punteggi\">
</form></center>";
} # fine if (@is_file("$percorso_cartella_dati/voti$num_giornata.txt"))

else {
if ($prima_parte_pos_file_voti or $num_giornata_file_voti == "SI") {
$posizione_file = $prima_parte_pos_file_voti;
if ($num_giornata_file_voti == "SI") {
#$num_giornata = ereg_replace("giornata","",$giornata);
$num_giornata = $num_giornata + $diff_num_giornata_file;
if ($num_giornata_file_voti_doppio == "SI") {
if (strlen($num_giornata) == 1) $num_giornata = "0".$num_giornata;
} # fine if ($num_giornata_file_voti_doppio == "SI")
$posizione_file .= "$num_giornata".$seconda_parte_pos_file_voti;
} # fine if ($num_giornata_file_voti == "SI")
echo "<form method=\"post\" action=\"giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"copia_file_voti\" value=\"Copia i voti\">
 dal file <input type=\"text\" name=\"posizione_file\" value=\"$posizione_file\" size=\"65\">
</form>";
} # fine if ($prima_parte_pos_file_voti or...
else echo "<center>Copia il file voti$num_giornata.txt nella cartella dati.</center><br>";
} # fine else if (@is_file("$percorso_cartella_dati/voti$num_giornata.txt"))
} # fine else if ($voti_esistenti == "SI"))

echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";

} # fine if ($pass_admin_errata == "NO")

include("$percorso_cartella_dati/foot.php");
?>
